@@ -1,6 +1,6 @@
 from django.apps import AppConfig as BaseAppConfig
 from django.conf import settings
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 
 from imagekit import register
 
